@@ -11,7 +11,7 @@
 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: combroyden.h,v 1.15 2001/03/26 00:04:02 beerli Exp $
+ $Id: combroyden.h,v 1.16 2001/05/01 16:36:09 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -30,7 +30,8 @@ extern void which_calc_like (long repkind);
 extern void calc_loci_param (nr_fmt *nr, double *lparam, double *olparam, 
 		      double *dv, double lamda, long nnn);
 extern void set_replicates (world_fmt * world, long repkind, long rep, long *repstart, long *repstop);
-extern void prepare_broyden (long kind, long repstart, long repstop, world_fmt * world, boolean * multilocus, long *Gmax);
+extern void prepare_broyden (long kind, world_fmt * world, 
+			     boolean * multilocus);
 extern void simple_loci_derivatives (double *d, nr_fmt * nr, 
 				     timearchive_fmt ** tyme, 
 				     long locus);
