@@ -14,7 +14,7 @@
                                                                                                                
  Peter Beerli, started 1997, Seattle
  beerli@genetics.washington.edu
-$Id: main.c,v 1.66 2001/04/08 04:24:44 beerli Exp $
+$Id: main.c,v 1.69 2001/05/17 05:46:48 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "definitions.h"
@@ -31,6 +31,7 @@ $Id: main.c,v 1.66 2001/04/08 04:24:44 beerli Exp $
 #include "tree.h"
 #include "tools.h"
 #include "profile.h"
+#include "aic.h"
 #include "lrt.h"
 #ifdef UEP
 #include "uep.h"
@@ -260,10 +261,10 @@ main (int argc, char **argv)
 	{
 	  //	  mpi_gmax_master(EARTH, Gmax);
 #endif
-	  if(options->aic)
-	    akaike_information(EARTH, &Gmax);
 	  if (EARTH->options->lratio->counter > 0)
 	    print_lratio_test (EARTH, &Gmax);
+	  if(options->aic)
+	    akaike_information(EARTH, &Gmax);
 #ifdef MPI
 	}
       //else
@@ -612,12 +613,13 @@ run_locus (world_fmt ** universe, int usize, option_fmt * options,
 		      sizeof (double) * EARTH->numpop2);
 	      log_param0 (EARTH->atl[rep][locus].param0,
 			  EARTH->atl[rep][locus].lparam0, EARTH->numpop2);
+	      copies2lcopies(&EARTH->atl[rep][locus]);
 	      EARTH->repkind = SINGLECHAIN;
 	      // single chain,  single replicate
 	      // estimateParameter(locus, rep, chain, type, 
 	      //                        EARTH, SINGLELOCUS);
 	      kind = SINGLELOCUS;
-	      *Gmax = (EARTH->G > *Gmax) ? EARTH->G+1 : (*Gmax) ; 
+	      *Gmax = (EARTH->G > *Gmax) ? EARTH->G+1 : (*Gmax) ;
 	      estimateParameter (rep, *Gmax, EARTH, options,
 				 EARTH->cov[locus], chain, type, kind,
 				 EARTH->repkind);
