@@ -10,7 +10,7 @@
 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: mcmc1.c,v 1.52 2000/12/12 18:27:38 beerli Exp $
+ $Id: mcmc1.c,v 1.53 2001/04/21 05:24:50 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "random.h"
@@ -108,7 +108,7 @@ metropolize (world_fmt * world, long g)
   /* ---------------------------------------------------------
      initialize local timelist and construct residual timelist 
      find the start node and snip of the branch and node below */
-#ifdef MAC
+#ifdef __MWERKS__
   eventloop ();
 #endif
   new_localtimelist (&timevector, &world->treetimes[0], world->numpop);
