@@ -196,6 +196,7 @@ typedef struct _option
   char title[LINESIZE + 1];
   lratio_fmt *lratio;
   boolean aic;
+  boolean fast_aic;
   double aicmod;
   char fsttype;
   boolean printfst;
@@ -337,9 +338,12 @@ timelist_fmt;
 typedef struct tarchive_fmt
 {
   long copies;
+  double lcopies;
+  double *point;
+  double *wait;
   double *km;
   double *kt;
-  long *p;
+  double *p;
   double *mindex;
 }
 tarchive_fmt;
@@ -354,6 +358,7 @@ typedef struct timearchive_fmt
   double thb;
   double alpha;
   tarchive_fmt *tl;
+  double *parameters;
   double *param;
   double *param0;
   double *lparam0;
@@ -465,6 +470,7 @@ typedef struct _worldoption
   double *plotyvalues;
   lratio_fmt *lratio;
   boolean aic;
+  boolean fast_aic;
   double aicmod;
   double lambda;
 #ifdef UEP
@@ -771,6 +777,7 @@ typedef struct _aic_fmt {
   double aic;
   char *pattern;
   long numparam;
+  double mle;
 } aic_fmt;
 
 
