@@ -13,7 +13,7 @@
  
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: options.c,v 1.74 2001/04/11 16:53:49 beerli Exp $
+ $Id: options.c,v 1.76 2001/05/01 16:36:09 beerli Exp $
 -------------------------------------------------------*/
 //#include <stdio.h>
 #include <time.h>
@@ -168,6 +168,7 @@ init_options (option_fmt * options)
   options->lratio->data[0].value1 = (char *) calloc (1, sizeof (char) * LINESIZE);
   options->lratio->data[0].value2 = (char *) calloc (1, sizeof (char) * LINESIZE);
   options->aic=FALSE;
+  options->fast_aic=FALSE;
   options->profile = ALL;
   options->profilemethod = 'p';
   options->df = 1;
@@ -861,7 +862,8 @@ void
 synchronize_param (world_fmt * world, option_fmt * options)
 {
   char type;
-  long i, j=0, z=0, zz = 0, len;
+  boolean found=FALSE;
+  long i, z=0, zz = 0, zzz=0, len;
   long ii, jj;
   long ns = 0, ss = 0, ss2 = 0, xs = 0, migm = 0;
   boolean allsymmig = FALSE;
@@ -910,18 +912,28 @@ synchronize_param (world_fmt * world, option_fmt * options)
 		  z = i;
 		  m2mm(z, world->numpop, &ii, &jj);
 		  zz = mm2m(jj,ii,world->numpop);
+		  zzz=0;
+		  found=FALSE;
+		  while(zzz<ss2)
+		    {
+		      if(world->options->sym2param[zzz][1]==zz)
+			found=TRUE;
+		      zzz++;
+		    }
+		  if(found)
+		    break;
 		  world->options->sym2param = (quad_fmt *) 
 		    realloc (world->options->sym2param, 
 			     sizeof (quad_fmt) * (ss2 + 2));
 		  world->options->sym2param[ss2][0] = zz;
 		  world->options->sym2param[ss2][1] = z;
-		  world->options->sym2param[ss2][2] = i;
-		  world->options->sym2param[ss2++][3] = j;
+		  world->options->sym2param[ss2][2] = ii;
+		  world->options->sym2param[ss2++][3] = jj;
 		  world->options->sym2n = ss2;
-		  summ = (world->param0[z] * world->param0[i] + 
-			  world->param0[zz] * world->param0[j]) / 2.;
-		  world->param0[z] = summ / world->param0[i];
-		  world->param0[zz] = summ / world->param0[j];
+		  summ = (world->param0[z] * world->param0[jj] + 
+			  world->param0[zz] * world->param0[ii]) / 2.;
+		  world->param0[z] = summ / world->param0[jj];
+		  world->param0[zz] = summ / world->param0[ii];
 		}
 	      break;
 	    case 'C':
@@ -1638,7 +1650,12 @@ long save_options_buffer(char *buffer, option_fmt *options, world_fmt * world)
       strcat(buffer, fp); 
     }
   if(options->aic)
-      sprintf(fp,"aic-modeltest=YES\n");
+    {
+      if(options->fast_aic)
+	sprintf(fp,"aic-modeltest=YES:FAST\n");
+      else
+	sprintf(fp,"aic-modeltest=YES\n");
+    }
   else
     sprintf(fp,"aic-modeltest=NO\n");
   strcat(buffer, fp); 
@@ -2040,7 +2057,19 @@ booleancheck (option_fmt * options, char *var, char *value)
 	  tmp = strtok (NULL, ":");
 	  if (tmp != NULL)
 	    {
-	      options->aicmod = atof (tmp);
+	      if(toupper(tmp[0])=='F')
+		{
+		  options->fast_aic=TRUE;
+		  tmp = strtok (NULL, ":");
+		  if (tmp != NULL)
+		    {
+		      options->aicmod = atof (tmp);
+		    }
+		  else
+		    options->aicmod = 2.;
+		}
+	      else
+		options->aicmod = atof (tmp);
 	    }
 	  else
 	    options->aicmod = 2.;
