@@ -7,7 +7,7 @@
 
  Peter Beerli 1997, Seattle
  beerli@genetics.washington.edu
- $Id: profile.c,v 1.50 2001/04/21 05:24:50 beerli Exp $
+ $Id: profile.c,v 1.51 2001/04/28 07:03:42 beerli Exp $
 
 -------------------------------------------------------*/
 
@@ -929,14 +929,50 @@ set_profile_param (double *param, long which, long *allwhich,
       profnum = 1 + zz;
       break;
     case 'S':
+      z = 0;
+      while (z<world->options->sym2n && 
+	     which != world->options->sym2param[z][0] && 
+	     which != world->options->sym2param[z][1])
+	z++;
+      param[world->options->sym2param[z][0]] = xval;
+      param[world->options->sym2param[z][1]] = xval;
+      if(which==world->options->sym2param[z][0])
+	{
+	  allwhich[0] = which;
+	  allwhich[1] = world->options->sym2param[z][1];
+	}
+      else
+	{
+	  allwhich[0] = world->options->sym2param[z][0];
+	  allwhich[1] = which;
+	}
+      xvals[0] = xval;
+      xvals[1] = xval;
+      if (has_fixed)
+	{
+	  addinvar (param, fixed, allwhich, xvals, 2, zz);
+	  free (fixed);
+	}
+      profnum = 2 + zz;
+      break;
     case 's':
       z = 0;
-      while (which != world->options->symparam[z][0] && which != world->options->symparam[z][1])
+      while (z<world->options->symn && 
+	     which != world->options->symparam[z][0] && 
+	     which != world->options->symparam[z][1])
 	z++;
       param[world->options->symparam[z][0]] = xval;
       param[world->options->symparam[z][1]] = xval;
-      allwhich[0] = which;
-      allwhich[1] = z;
+      if(which==world->options->symparam[z][0])
+	{
+	  allwhich[0] = which;
+	  allwhich[1] = world->options->symparam[z][1];
+	}
+      else
+	{
+	  allwhich[0] = world->options->symparam[z][0];
+	  allwhich[1] = which;
+	}
       xvals[0] = xval;
       xvals[1] = xval;
       if (has_fixed)
