@@ -10,7 +10,7 @@
 
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
- $Id: tools.h,v 1.13 2001/03/09 16:29:19 beerli Exp $
+ $Id: tools.h,v 1.15 2001/05/17 05:46:48 beerli Exp $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -29,9 +29,11 @@ extern void invert_matrix (double **a, long nsize);
 extern boolean nrcheck (double **m, double **tm, double *v, long nrows, double *r1, double *r2, boolean do_newton);
 extern double rannor (double mean, double sd);
 extern double find_chi (long df, double prob);
+extern double probchiboundary(double chi, long zeros, long nonzeros);
+extern double chiboundary (long zeros, long nonzeros, double alpha);
 extern double probchi (long df, double chi);
 extern double chisquare (long df, double alpha);
-extern void gamma_rates (double *rate, long categs, char *input);
+extern void gamma_rates (double *rate, double *probcat, long categs, char *input);
 #ifndef HAVE_LGAMMA
 extern double mylgamma (double z);
 #endif
